# BITPlan ProfiWiki
BITPlan's Professional SemanticMediaWiki

[![Join the discussion at https://github.com/BITPlan/ProfiWiki/discussions](https://img.shields.io/github/discussions/BITPlan/ProfiWiki)](https://github.com/BITPlan/ProfiWiki/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/ProfiWiki)](https://pypi.org/project/ProfiWiki/)
[![Github Actions Build](https://github.com/BITPlan/ProfiWiki/actions/workflows/build.yml/badge.svg)](https://github.com/BITPlan/ProfiWiki/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/ProfiWiki.svg)](https://pypi.python.org/pypi/ProfiWiki/)
[![GitHub issues](https://img.shields.io/github/issues/BITPlan/ProfiWiki.svg)](https://github.com/BITPlan/ProfiWiki/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/BITPlan/ProfiWiki.svg)](https://github.com/BITPlan/ProfiWiki/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://BITPlan.github.io/ProfiWiki/)
[![License](https://img.shields.io/github/license/BITPlan/ProfiWiki.svg)](https://www.apache.org/licenses/LICENSE-2.0)
[![BITPlan](http://wiki.bitplan.com/images/wiki/thumb/3/38/BITPlanLogoFontLessTransparent.png/198px-BITPlanLogoFontLessTransparent.png)](http://www.bitplan.com)

[![Mediawiki](https://upload.wikimedia.org/wikipedia/commons/thumb/a/a3/MediaWiki_logo_1.png/128px-MediaWiki_logo_1.png)](https://www.mediawiki.org/wiki/MediaWiki)
[![SemanticMediaWiki](http://semantic-mediawiki.org/w/images/7/7c/SMW_logo_142px.png)](http://www.semantic-mediawiki.org/)

Semantic MediaWiki with fully automated install.
Will get your Semantic MediaWiki running in a few minutes.

### Documentation
* [Wiki](https://wiki.bitplan.com/index.php/ProfiWiki)
### Features
* Docker compose based
* based on official Mediawiki docker image
### Links
* https://github.com/SemanticMediaWiki/SemanticMediaWiki/issues/1218
